Documentation
¶
Overview ¶
Package cite holds tools and types to ease citing software hosted on Codeberg.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Repository ¶
type Repository struct {
Owner string // owner of this repository, eg: "sbinet"
Name string // name of this repository, eg: "cite-codeberg"
}
Repository models a forgejo repository.
func Repo ¶
func Repo(fullname string) (rep Repository, err error)
Repo creates a forgejo repository handle using its fullname.
Example:
rep, err := cite.Repo("sbinet/cite-codeberg")
func (Repository) FullName ¶
func (r Repository) FullName() string
FullName returns the fully qualified name of this repository. ie: "sbinet/cite-codeberg".
Directories
¶
| Path | Synopsis |
|---|---|
|
cmd
|
|
|
zenodo-release
command
Command zenodo-release publishes a Codeberg-hosted release to Zenodo.
|
Command zenodo-release publishes a Codeberg-hosted release to Zenodo. |
|
Package zenodo publishes a software citation to Zenodo.
|
Package zenodo publishes a software citation to Zenodo. |
Click to show internal directories.
Click to hide internal directories.